.. include global.rst

parso - A Python Parser
=======================

Release v\ |release|. (:doc:`Installation <docs/installation>`)

.. automodule:: parso

.. _toc:

Docs
----

.. toctree::
   :maxdepth: 2

   docs/installation
   docs/usage
   docs/parser-tree
   docs/development


.. _resources:

Resources
---------

- `Source Code on Github <https://github.com/davidhalter/parso>`_
- `GitHub Actions Testing <https://github.com/davidhalter/parso/actions>`_
- `Python Package Index <http://pypi.python.org/pypi/parso/>`_
